
# Slot: distribution download url




URI: [biolink:distribution_download_url](https://w3id.org/biolink/vocab/distribution_download_url)


## Domain and Range

[DatasetDistribution](DatasetDistribution.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [DatasetDistribution](DatasetDistribution.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | dcat:downloadURL |

